@@ -22,10 +22,12 @@ import cfnlint.data.AdditionalSpecs
 
 LOGGER = logging.getLogger(__name__)
 
-REGISTRY_SCHEMA_ZIP = 'https://schema.cloudformation.us-east-1.amazonaws.com/CloudformationSchema.zip'
+REGISTRY_SCHEMA_ZIP = (
+    'https://schema.cloudformation.us-east-1.amazonaws.com/CloudformationSchema.zip'
+)
 
 
-def update_resource_specs(force: bool=False):
+def update_resource_specs(force: bool = False):
     # Pool() uses cpu count if no number of processors is specified
     # Pool() only implements the Context Manager protocol from Python3.3 onwards,
     # so it will fail Python2.7 style linting, as well as throw AttributeError
@@ -43,9 +45,11 @@ def update_resource_specs(force: bool=False):
             update_resource_spec(region, url, schema_cache, force)
 
 
-def update_resource_spec(region, url, schema_cache, force: bool=False):
-    """ Update a single resource spec """
-    filename = os.path.join(os.path.dirname(cfnlint.__file__), f'data/CloudSpecs/{region}.json')
+def update_resource_spec(region, url, schema_cache, force: bool = False):
+    """Update a single resource spec"""
+    filename = os.path.join(
+        os.path.dirname(cfnlint.__file__), f'data/CloudSpecs/{region}.json'
+    )
 
     multiprocessing_logger = multiprocessing.log_to_stderr()
 
@@ -58,7 +62,10 @@ def update_resource_spec(region, url, schema_cache, force: bool=False):
     spec_content = get_url_content(url, caching=True)
 
     multiprocessing_logger.debug(
-        'A more recent version of %s was found, and will be downloaded to %s', url, filename)
+        'A more recent version of %s was found, and will be downloaded to %s',
+        url,
+        filename,
+    )
     spec = json.loads(spec_content)
 
     # Patch the files
@@ -98,8 +105,9 @@ def update_resource_spec(region, url, schema_cache, force: bool=False):
                         except:  # pylint: disable=bare-except
                             pass
             # Debug as the parent element isn't supported in the region
-            LOGGER.debug('Parent element not found for patch (%s) in region %s',
-                         patch, region)
+            LOGGER.debug(
+                'Parent element not found for patch (%s) in region %s', patch, region
+            )
 
     botocore_cache = {}
 
@@ -112,10 +120,16 @@ def update_resource_spec(region, url, schema_cache, force: bool=False):
                     service = '/'.join(service_and_type[:-1])
                     botocore_type = service_and_type[-1]
                     if service not in botocore_cache:
-                        botocore_cache[service] = json.loads(get_url_content(
-                            'https://raw.githubusercontent.com/boto/botocore/master/botocore/data/' + service + '/service-2.json'))
+                        botocore_cache[service] = json.loads(
+                            get_url_content(
+                                'https://raw.githubusercontent.com/boto/botocore/master/botocore/data/'
+                                + service
+                                + '/service-2.json'
+                            )
+                        )
                     new_obj['AllowedValues'] = sorted(
-                        botocore_cache[service]['shapes'][botocore_type]['enum'])
+                        botocore_cache[service]['shapes'][botocore_type]['enum']
+                    )
                 else:
                     new_obj[key] = search_and_replace_botocore_types(value)
             return new_obj
@@ -165,25 +179,59 @@ def update_documentation(rules):
 
         # Add the rules
         new_file.write(
-            '(_This documentation is generated by running `cfn-lint --update-documentation`, do not alter this manually_)\n\n')
+            '(_This documentation is generated by running `cfn-lint --update-documentation`, do not alter this manually_)\n\n'
+        )
         new_file.write(
-            'The following **{}** rules are applied by this linter:\n\n'.format(len(sorted_rules) + 3))
+            f'The following **{len(sorted_rules) + 3}** rules are applied by this linter:\n\n'
+        )
         new_file.write(
-            '| Rule ID  | Title | Description | Config<br />(Name:Type:Default) | Source | Tags |\n')
-        new_file.write('| -------- | ----- | ----------- | ---------- | ------ | ---- |\n')
+            '| Rule ID  | Title | Description | Config<br />(Name:Type:Default) | Source | Tags |\n'
+        )
+        new_file.write(
+            '| -------- | ----- | ----------- | ---------- | ------ | ---- |\n'
+        )
 
-        rule_output = '| [{0}<a name="{0}"></a>]({6}) | {1} | {2} | {3} | [Source]({4}) | {5} |\n'
+        rule_output = (
+            '| [{0}<a name="{0}"></a>]({6}) | {1} | {2} | {3} | [Source]({4}) | {5} |\n'
+        )
 
-        for rule in [cfnlint.rules.ParseError(), cfnlint.rules.TransformError(), cfnlint.rules.RuleError()] + sorted_rules:
+        for rule in [
+            cfnlint.rules.ParseError(),
+            cfnlint.rules.TransformError(),
+            cfnlint.rules.RuleError(),
+        ] + sorted_rules:
             # pylint: disable=invalid-string-quote
-            rule_source_code_file = '../' + subprocess.check_output(['git', 'grep', '-l', "id = '" + rule.id + "'", 'src/cfnlint/rules/']).decode(
-                'ascii').strip()
+            rule_source_code_file = (
+                '../'
+                + subprocess.check_output(
+                    [
+                        'git',
+                        'grep',
+                        '-l',
+                        "id = '" + rule.id + "'",
+                        'src/cfnlint/rules/',
+                    ]
+                )
+                .decode('ascii')
+                .strip()
+            )
             rule_id = rule.id + '*' if rule.experimental else rule.id
-            tags = ','.join('`{0}`'.format(tag) for tag in rule.tags)
-            config = '<br />'.join('{0}:{1}:{2}'.format(key, values.get('type'), values.get('default'))
-                                   for key, values in rule.config_definition.items())
-            new_file.write(rule_output.format(rule_id, rule.shortdesc,
-                                              rule.description, config, rule.source_url, tags, rule_source_code_file))
+            tags = ','.join(f'`{tag}`' for tag in rule.tags)
+            config = '<br />'.join(
+                f'{key}:{values.get("type")}:{values.get("default")}'
+                for key, values in rule.config_definition.items()
+            )
+            new_file.write(
+                rule_output.format(
+                    rule_id,
+                    rule.shortdesc,
+                    rule.description,
+                    config,
+                    rule.source_url,
+                    tags,
+                    rule_source_code_file,
+                )
+            )
         new_file.write('\n\\* experimental rules\n')
 
 
@@ -191,26 +239,38 @@ def patch_spec(content, region):
     """Patch the spec file"""
     LOGGER.info('Patching spec file for region "%s"', region)
 
-    append_dir = os.path.join(os.path.dirname(__file__), 'data', 'ExtendedSpecs', region)
+    append_dir = os.path.join(
+        os.path.dirname(__file__), 'data', 'ExtendedSpecs', region
+    )
     for dirpath, _, filenames in os.walk(append_dir):
         filenames.sort()
         for filename in fnmatch.filter(filenames, '*.json'):
             file_path = os.path.basename(filename)
-            module = dirpath.replace('%s' % append_dir, '%s' % region).replace(os.path.sep, '.')
+            module = dirpath.replace(f'{append_dir}', f'{region}').replace(
+                os.path.sep, '.'
+            )
             LOGGER.info('Processing %s/%s', module, file_path)
-            all_patches = jsonpatch.JsonPatch(cfnlint.helpers.load_resource(
-                'cfnlint.data.ExtendedSpecs.{}'.format(module), file_path))
+            all_patches = jsonpatch.JsonPatch(
+                cfnlint.helpers.load_resource(
+                    f'cfnlint.data.ExtendedSpecs.{module}', file_path
+                )
+            )
 
             # Process the generic patches 1 by 1 so we can "ignore" failed ones
             for all_patch in all_patches:
                 try:
                     jsonpatch.JsonPatch([all_patch]).apply(content, in_place=True)
                 except jsonpatch.JsonPatchConflict:
-                    LOGGER.debug('Patch (%s) not applied in region %s', all_patch, region)
+                    LOGGER.debug(
+                        'Patch (%s) not applied in region %s', all_patch, region
+                    )
                 except jsonpatch.JsonPointerException:
                     # Debug as the parent element isn't supported in the region
-                    LOGGER.debug('Parent element not found for patch (%s) in region %s',
-                                 all_patch, region)
+                    LOGGER.debug(
+                        'Parent element not found for patch (%s) in region %s',
+                        all_patch,
+                        region,
+                    )
 
     return content
 
@@ -221,8 +281,8 @@ def update_iam_policies():
     url = 'https://awspolicygen.s3.amazonaws.com/js/policies.js'
 
     filename = os.path.join(
-        os.path.dirname(cfnlint.data.AdditionalSpecs.__file__),
-        'Policies.json')
+        os.path.dirname(cfnlint.data.AdditionalSpecs.__file__), 'Policies.json'
+    )
     LOGGER.debug('Downloading policies %s into %s', url, filename)
 
     content = get_url_content(url)
@@ -247,7 +307,6 @@ def update_iam_policies():
 
 
 def get_schema_value_types():
-
     def resolve_refs(properties, schema):
         results = {}
         name = None
@@ -286,27 +345,58 @@ def get_schema_value_types():
                     subname = propname
                 if propdetails.get('properties'):
                     if subname not in names:
-                        results.update(get_object_details(
-                            names + [subname], propdetails.get('properties'), schema))
-                elif propdetails.get('oneOf') or propdetails.get('anyOf') or propdetails.get('allOf'):
+                        results.update(
+                            get_object_details(
+                                names + [subname], propdetails.get('properties'), schema
+                            )
+                        )
+                elif (
+                    propdetails.get('oneOf')
+                    or propdetails.get('anyOf')
+                    or propdetails.get('allOf')
+                ):
                     LOGGER.info(
-                        'Type %s object for %s has only oneOf,anyOf, or allOf properties', names[0], propname)
+                        'Type %s object for %s has only oneOf,anyOf, or allOf properties',
+                        names[0],
+                        propname,
+                    )
                     continue
             elif t not in ['string', 'integer', 'number', 'boolean']:
                 if propdetails.get('$ref'):
-                    results.update(get_object_details(
-                        names + [propname], schema.get('definitions').get(t.get('$ref').split('/')[-1]), schema))
+                    results.update(
+                        get_object_details(
+                            names + [propname],
+                            schema.get('definitions').get(t.get('$ref').split('/')[-1]),
+                            schema,
+                        )
+                    )
                 elif isinstance(t, list):
-                    LOGGER.info('Type for %s object and %s property is a list', names[0], propname)
+                    LOGGER.info(
+                        'Type for %s object and %s property is a list',
+                        names[0],
+                        propname,
+                    )
                 else:
-                    LOGGER.info('Unable to handle %s object for %s property', names[0], propname)
+                    LOGGER.info(
+                        'Unable to handle %s object for %s property', names[0], propname
+                    )
             elif t == 'string':
                 if not results.get('.'.join(names + [propname])):
-                    if propdetails.get('pattern') or (propdetails.get('minLength') and propdetails.get('maxLength')) or propdetails.get('enum'):
+                    if (
+                        propdetails.get('pattern')
+                        or (
+                            propdetails.get('minLength')
+                            and propdetails.get('maxLength')
+                        )
+                        or propdetails.get('enum')
+                    ):
                         results['.'.join(names + [propname])] = {}
                 if propdetails.get('pattern'):
                     p = propdetails.get('pattern')
-                    if '.'.join(names + [propname]) == 'AWS::OpsWorksCM::Server.CustomPrivateKey':
+                    if (
+                        '.'.join(names + [propname])
+                        == 'AWS::OpsWorksCM::Server.CustomPrivateKey'
+                    ):
                         # one off exception to handle a weird parsing issue in python 2.7
                         continue
                     # python 3 has the ability to test isascii
@@ -319,35 +409,45 @@ def get_schema_value_types():
                         if '\\p{' in p:
                             continue
                         re.compile(p, re.UNICODE)
-                        results['.'.join(names + [propname])].update({
-                            'AllowedPatternRegex': p
-                        })
-                    except:  #pylint: disable=bare-except
+                        results['.'.join(names + [propname])].update(
+                            {'AllowedPatternRegex': p}
+                        )
+                    except:  # pylint: disable=bare-except
                         LOGGER.info(
-                            'Unable to handle regex for type %s and property %s with regex %s', names[0], propname, p)
+                            'Unable to handle regex for type %s and property %s with regex %s',
+                            names[0],
+                            propname,
+                            p,
+                        )
                 if propdetails.get('minLength') and propdetails.get('maxLength'):
-                    results['.'.join(names + [propname])].update({
-                        'StringMin': propdetails.get('minLength'),
-                        'StringMax': propdetails.get('maxLength'),
-                    })
+                    results['.'.join(names + [propname])].update(
+                        {
+                            'StringMin': propdetails.get('minLength'),
+                            'StringMax': propdetails.get('maxLength'),
+                        }
+                    )
                 if propdetails.get('enum'):
-                    results['.'.join(names + [propname])].update({
-                        'AllowedValues': propdetails.get('enum')
-                    })
+                    results['.'.join(names + [propname])].update(
+                        {'AllowedValues': propdetails.get('enum')}
+                    )
             elif t in ['number', 'integer']:
                 if not results.get('.'.join(names + [propname])):
                     if propdetails.get('minimum') and propdetails.get('maximum'):
                         results['.'.join(names + [propname])] = {}
                 if propdetails.get('minimum') and propdetails.get('maximum'):
-                    results['.'.join(names + [propname])].update({
-                        'NumberMin': propdetails.get('minimum'),
-                        'NumberMax': propdetails.get('maximum'),
-                    })
+                    results['.'.join(names + [propname])].update(
+                        {
+                            'NumberMin': propdetails.get('minimum'),
+                            'NumberMax': propdetails.get('maximum'),
+                        }
+                    )
 
         return results
 
     def process_schema(schema):
-        details = get_object_details([schema.get('typeName')], schema.get('properties'), schema)
+        details = get_object_details(
+            [schema.get('typeName')], schema.get('properties'), schema
+        )
 
         # Remove duplicates
         vtypes = {}
@@ -368,7 +468,7 @@ def get_schema_value_types():
                     r_type = 'ResourceTypes'
                 element = {
                     'op': 'add',
-                    'path': '/%s/%s/Properties/%s/Value' % (r_type, '.'.join(n.split('.')[0:-1]), n.split('.')[-1]),
+                    'path': f'/{r_type}/{".".join(n.split(".")[0:-1])}/Properties/{n.split(".")[-1]}/Value',
                     'value': {
                         'ValueType': n,
                     },
@@ -377,7 +477,7 @@ def get_schema_value_types():
                 for s, vs in v.items():
                     element = {
                         'op': 'add',
-                        'path': '/ValueTypes/%s/%s' % (n, s),
+                        'path': f'/ValueTypes/{n}/{s}',
                         'value': vs,
                     }
                     patch.append(element)
@@ -387,21 +487,20 @@ def get_schema_value_types():
         return patches
 
     req = Request(REGISTRY_SCHEMA_ZIP)
-    res = urlopen(req)
 
     results = []
-
-    with zipfile.ZipFile(BytesIO(res.read())) as z:
-        for f in z.namelist():
-            with z.open(f) as d:
-                if not isinstance(d, str):
-                    data = d.read()
-                else:
-                    data = d
-                if isinstance(data, bytes):
-                    data = data.decode('utf-8')
-                schema = json.loads(data)
-                patches = process_schema(schema)
-                results.extend(patches)
+    with urlopen(req) as res:
+        with zipfile.ZipFile(BytesIO(res.read())) as z:
+            for f in z.namelist():
+                with z.open(f) as d:
+                    if not isinstance(d, str):
+                        data = d.read()
+                    else:
+                        data = d
+                    if isinstance(data, bytes):
+                        data = data.decode('utf-8')
+                    schema = json.loads(data)
+                    patches = process_schema(schema)
+                    results.extend(patches)
 
     return results
