@@ -9,6 +9,7 @@ from cfnlint.decode.node import sub_node
 
 class SubUnneeded(CloudFormationLintRule):
     """Check if Sub is using a variable"""
+
     id = 'W1020'
     shortdesc = 'Sub isn\'t needed if it doesn\'t have a variable defined'
     description = 'Checks sub strings to see if a variable is defined.'
@@ -25,8 +26,13 @@ class SubUnneeded(CloudFormationLintRule):
             result_path = path[:] + ['Fn::Sub']
             if sub_obj.is_valid():
                 if not sub_obj.get_string_vars():
-                    message = 'Fn::Sub isn\'t needed because there are no variables at {0}'
-                    matches.append(RuleMatch(
-                        result_path, message.format('/'.join(map(str, result_path)))))
+                    message = (
+                        'Fn::Sub isn\'t needed because there are no variables at {0}'
+                    )
+                    matches.append(
+                        RuleMatch(
+                            result_path, message.format('/'.join(map(str, result_path)))
+                        )
+                    )
 
         return matches
