@@ -8,9 +8,12 @@ from cfnlint.rules.common import approaching_name_limit
 
 class LimitName(CloudFormationLintRule):
     """Check maximum Output name size limit"""
+
     id = 'I6011'
     shortdesc = 'Output name limit'
-    description = 'Check the size of Output names in the template is approaching the upper limit'
+    description = (
+        'Check the size of Output names in the template is approaching the upper limit'
+    )
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html'
     tags = ['outputs', 'limits']
 
