@@ -8,6 +8,7 @@ from cfnlint.rules import RuleMatch
 
 class ImportValue(CloudFormationLintRule):
     """Check if a Output is done of another output"""
+
     id = 'W6001'
     shortdesc = 'Check Outputs using ImportValue'
     description = 'Check if the Output value is set using ImportValue, so creating an Output of an Output'
@@ -33,7 +34,11 @@ class ImportValue(CloudFormationLintRule):
                 # ImportValue can be used within other intrinic function, exclude those
                 if importvalue_tree[3] == 'Fn::ImportValue':
                     message = 'The value of output ({0}) is imported from another output ({1})'
-                    matches.append(RuleMatch(importvalue_tree, message.format(
-                        importvalue_tree[1], importvalue_tree[-1])))
+                    matches.append(
+                        RuleMatch(
+                            importvalue_tree,
+                            message.format(importvalue_tree[1], importvalue_tree[-1]),
+                        )
+                    )
 
         return matches
