@@ -9,6 +9,7 @@ from cfnlint.rules import RuleMatch
 
 class CodepipelineStageActions(CloudFormationLintRule):
     """Check if CodePipeline Stage Actions are set up properly."""
+
     id = 'E2541'
     shortdesc = 'CodePipeline Stage Actions'
     description = 'See if CodePipeline stage actions are set correctly'
@@ -29,7 +30,7 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 'ECR': {
                     'InputArtifactRange': 0,
                     'OutputArtifactRange': 1,
-                }
+                },
             },
             'Test': {
                 'CodeBuild': {
@@ -39,7 +40,7 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 'DeviceFarm': {
                     'InputArtifactRange': 1,
                     'OutputArtifactRange': 0,
-                }
+                },
             },
             'Build': {
                 'CodeBuild': {
@@ -88,7 +89,7 @@ class CodepipelineStageActions(CloudFormationLintRule):
                     'InputArtifactRange': (0, 5),
                     'OutputArtifactRange': (0, 5),
                 }
-            }
+            },
         },
         'ThirdParty': {
             'Source': {
@@ -134,11 +135,19 @@ class CodepipelineStageActions(CloudFormationLintRule):
         category = action_type_id.get('Category')
         provider = action_type_id.get('Provider')
 
-        if isinstance(owner, dict) or isinstance(category, dict) or isinstance(provider, dict):
-            self.logger.debug('owner, category, provider need to be strings to validate. Skipping.')
+        if (
+            isinstance(owner, dict)
+            or isinstance(category, dict)
+            or isinstance(provider, dict)
+        ):
+            self.logger.debug(
+                'owner, category, provider need to be strings to validate. Skipping.'
+            )
             return matches
 
-        constraints = self.CONSTRAINTS.get(owner, {}).get(category, {}).get(provider, {})
+        constraints = (
+            self.CONSTRAINTS.get(owner, {}).get(category, {}).get(provider, {})
+        )
         if not constraints:
             return matches
         artifact_count = len(action.get(artifact_type, []))
@@ -146,44 +155,29 @@ class CodepipelineStageActions(CloudFormationLintRule):
         constraint_key = self.KEY_MAP[artifact_type]
         if isinstance(constraints[constraint_key], tuple):
             min_, max_ = constraints[constraint_key]
-            if not (min_ <= artifact_count <= max_):
+            if not min_ <= artifact_count <= max_:
                 message = (
-                    'Action "{action}" declares {number} {artifact_type} which is not in '
-                    'expected range [{a}, {b}].'
-                ).format(
-                    action=action['Name'],
-                    number=artifact_count,
-                    artifact_type=artifact_type,
-                    a=min_,
-                    b=max_
+                    f'Action "{action["Name"]}" declares {artifact_count} {artifact_type} which is not in '
+                    f'expected range [{min_}, {max_}].'
                 )
                 if scenario:
                     scenario_text = ' and '.join(
-                        ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                        [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
+                    )
                     message = message + ' When ' + scenario_text
-                matches.append(RuleMatch(
-                    path + [artifact_type],
-                    message
-                ))
+                matches.append(RuleMatch(path + [artifact_type], message))
         else:
             if artifact_count != constraints[constraint_key]:
                 message = (
-                    'Action "{action}" declares {number} {artifact_type} which is not the '
-                    'expected number [{a}].'
-                ).format(
-                    action=action['Name'],
-                    number=artifact_count,
-                    artifact_type=artifact_type,
-                    a=constraints[constraint_key]
+                    f'Action "{action["Name"]}" declares {artifact_count} {artifact_type} which is not the '
+                    f'expected number [{constraints[constraint_key]}].'
                 )
                 if scenario:
                     scenario_text = ' and '.join(
-                        ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                        [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
+                    )
                     message = message + ' When ' + scenario_text
-                matches.append(RuleMatch(
-                    path + [artifact_type],
-                    message
-                ))
+                matches.append(RuleMatch(path + [artifact_type], message))
 
         return matches
 
@@ -197,27 +191,31 @@ class CodepipelineStageActions(CloudFormationLintRule):
 
         version = action.get('ActionTypeId', {}).get('Version')
         if isinstance(version, dict):
-            self.logger.debug('Unable to validate version when an object is used.  Skipping')
+            self.logger.debug(
+                'Unable to validate version when an object is used.  Skipping'
+            )
         elif isinstance(version, (str)):
             if not LENGTH_MIN <= len(version) <= LENGTH_MAX:
                 message = 'Version string ({0}) must be between {1} and {2} characters in length.'
                 if scenario:
                     scenario_text = ' and '.join(
-                        ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                        [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
+                    )
                     message = message + ' When ' + scenario_text
-                matches.append(RuleMatch(
-                    path + ['ActionTypeId', 'Version'],
-                    message.format(version, LENGTH_MIN, LENGTH_MAX)))
+                matches.append(
+                    RuleMatch(
+                        path + ['ActionTypeId', 'Version'],
+                        message.format(version, LENGTH_MIN, LENGTH_MAX),
+                    )
+                )
             elif not re.match(REGEX_VERSION_STRING, version):
                 message = 'Version string must match the pattern [0-9A-Za-z_-]+.'
                 if scenario:
                     scenario_text = ' and '.join(
-                        ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                        [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
+                    )
                     message = message + ' When ' + scenario_text
-                matches.append(RuleMatch(
-                    path + ['ActionTypeId', 'Version'],
-                    message
-                ))
+                matches.append(RuleMatch(path + ['ActionTypeId', 'Version'], message))
         return matches
 
     def check_names_unique(self, action, path, action_names, scenario):
@@ -227,12 +225,11 @@ class CodepipelineStageActions(CloudFormationLintRule):
         action_name = action.get('Name')
         if isinstance(action_name, str):
             if action.get('Name') in action_names:
-                message = 'All action names within a stage must be unique ({name}).'.format(
-                    name=action.get('Name')
-                )
+                message = f'All action names within a stage must be unique ({action.get("Name")}).'
                 if scenario:
                     scenario_text = ' and '.join(
-                        ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                        [f'condition "{k}" is {v}' for (k, v) in scenario.items()]
+                    )
                     message = message + ' When ' + scenario_text
                 matches.append(RuleMatch(path + ['Name'], message))
             action_names.add(action.get('Name'))
@@ -249,14 +246,18 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 artifact_name = input_artifact.get('Name')
                 if isinstance(artifact_name, str):
                     if not artifact_name in artifact_names:
-                        message = 'Every input artifact for an action must match the output artifact of an action earlier in the pipeline ({name}).'.format(
-                            name=artifact_name
-                        )
+                        message = f'Every input artifact for an action must match the output artifact of an action earlier in the pipeline ({artifact_name}).'
                         if scenario:
                             scenario_text = ' and '.join(
-                                ['condition "%s" is %s' % (k, v) for (k, v) in scenario.items()])
+                                [
+                                    f'condition "{k}" is {v}'
+                                    for (k, v) in scenario.items()
+                                ]
+                            )
                             message = message + ' When ' + scenario_text
-                        matches.append(RuleMatch(path + ['InputArtifacts', 'Name'], message))
+                        matches.append(
+                            RuleMatch(path + ['InputArtifacts', 'Name'], message)
+                        )
 
         output_artifacts = action.get('OutputArtifacts')
         if isinstance(output_artifacts, list):
@@ -264,10 +265,10 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 artifact_name = output_artifact.get('Name')
                 if isinstance(artifact_name, str):
                     if artifact_name in artifact_names:
-                        message = 'Every output artifact in the pipeline must have a unique name. ({name})'.format(
-                            name=artifact_name
+                        message = f'Every output artifact in the pipeline must have a unique name. ({artifact_name})'
+                        matches.append(
+                            RuleMatch(path + ['OutputArtifacts', 'Name'], message)
                         )
-                        matches.append(RuleMatch(path + ['OutputArtifacts', 'Name'], message))
                     artifact_names.add(artifact_name)
 
         return matches
@@ -280,7 +281,8 @@ class CodepipelineStageActions(CloudFormationLintRule):
 
         for resource in resources:
             scenarios = cfn.get_object_without_nested_conditions(
-                resource['Value'], resource['Path'])
+                resource['Value'], resource['Path']
+            )
             for scenario in scenarios:
                 conditions = scenario.get('Scenario')
                 path = resource['Path'] + ['Stages']
@@ -290,30 +292,49 @@ class CodepipelineStageActions(CloudFormationLintRule):
                 s_stages = properties.get('Stages')
                 if not isinstance(s_stages, list):
                     self.logger.debug(
-                        'Stages not list. Should have been caught by generic linting.')
+                        'Stages not list. Should have been caught by generic linting.'
+                    )
                     return matches
                 for s_stage_i, s_stage_v in enumerate(s_stages):
                     action_names = set()
                     s_actions = s_stage_v.get('Actions')
                     if not isinstance(s_actions, list):
                         self.logger.debug(
-                            'Actions not list. Should have been caught by generic linting.')
+                            'Actions not list. Should have been caught by generic linting.'
+                        )
                         return matches
 
                     for s_action_i, s_action_v in enumerate(s_actions):
                         try:
                             full_path = path + [s_stage_i, 'Actions', s_action_i]
-                            matches.extend(self.check_names_unique(
-                                s_action_v, full_path, action_names, conditions))
-                            matches.extend(self.check_version(s_action_v, full_path, conditions))
-                            matches.extend(self.check_artifact_counts(
-                                s_action_v, 'InputArtifacts', full_path, conditions))
-                            matches.extend(self.check_artifact_counts(
-                                s_action_v, 'OutputArtifacts', full_path, conditions))
-                            matches.extend(self.check_artifact_names(
-                                s_action_v, full_path, artifact_names, conditions))
+                            matches.extend(
+                                self.check_names_unique(
+                                    s_action_v, full_path, action_names, conditions
+                                )
+                            )
+                            matches.extend(
+                                self.check_version(s_action_v, full_path, conditions)
+                            )
+                            matches.extend(
+                                self.check_artifact_counts(
+                                    s_action_v, 'InputArtifacts', full_path, conditions
+                                )
+                            )
+                            matches.extend(
+                                self.check_artifact_counts(
+                                    s_action_v, 'OutputArtifacts', full_path, conditions
+                                )
+                            )
+                            matches.extend(
+                                self.check_artifact_names(
+                                    s_action_v, full_path, artifact_names, conditions
+                                )
+                            )
                         except AttributeError as err:
-                            self.logger.debug('Got AttributeError. Should have been caught by generic linting. '
-                                            'Ignoring the error here: %s', str(err))
+                            self.logger.debug(
+                                'Got AttributeError. Should have been caught by generic linting. '
+                                'Ignoring the error here: %s',
+                                str(err),
+                            )
 
         return matches
