@@ -9,14 +9,19 @@ from cfnlint.rules import RuleMatch
 
 class DeprecatedRuntimeEnd(DeprecatedRuntime):
     """Check if EOL Lambda Function Runtimes are used"""
+
     id = 'E2531'
     shortdesc = 'Check if EOL Lambda Function Runtimes are used'
-    description = 'Check if an EOL Lambda Runtime is specified and give an error if used. '
-    source_url = 'https://docs.aws.amazon.com/lambda/latest/dg/runtime-support-policy.html'
+    description = (
+        'Check if an EOL Lambda Runtime is specified and give an error if used. '
+    )
+    source_url = (
+        'https://docs.aws.amazon.com/lambda/latest/dg/runtime-support-policy.html'
+    )
     tags = ['resources', 'lambda', 'runtime']
 
     def check_runtime(self, runtime_value, path):
-        """ Check if the given runtime is valid"""
+        """Check if the given runtime is valid"""
         matches = []
 
         runtime = self.deprecated_runtimes.get(runtime_value)
@@ -27,7 +32,8 @@ class DeprecatedRuntimeEnd(DeprecatedRuntime):
                     RuleMatch(
                         path,
                         message.format(
-                            runtime_value,
-                            runtime['deprecated'],
-                            runtime['successor'])))
+                            runtime_value, runtime['deprecated'], runtime['successor']
+                        ),
+                    )
+                )
         return matches
