@@ -9,19 +9,28 @@ from cfnlint.rules import RuleMatch
 
 class DeprecatedRuntimeEol(DeprecatedRuntime):
     """Check if EOL Lambda Function Runtimes are used"""
+
     id = 'W2531'
     shortdesc = 'Check if EOL Lambda Function Runtimes are used'
-    description = 'Check if an EOL Lambda Runtime is specified and give a warning if used. '
-    source_url = 'https://docs.aws.amazon.com/lambda/latest/dg/runtime-support-policy.html'
+    description = (
+        'Check if an EOL Lambda Runtime is specified and give a warning if used. '
+    )
+    source_url = (
+        'https://docs.aws.amazon.com/lambda/latest/dg/runtime-support-policy.html'
+    )
     tags = ['resources', 'lambda', 'runtime']
 
     def check_runtime(self, runtime_value, path):
-        """ Check if the given runtime is valid"""
+        """Check if the given runtime is valid"""
         matches = []
 
         runtime = self.deprecated_runtimes.get(runtime_value)
         if runtime:
-            if datetime.strptime(runtime['eol'], '%Y-%m-%d') < self.current_date and datetime.strptime(runtime['deprecated'], '%Y-%m-%d') > self.current_date:
+            if (
+                datetime.strptime(runtime['eol'], '%Y-%m-%d') < self.current_date
+                and datetime.strptime(runtime['deprecated'], '%Y-%m-%d')
+                > self.current_date
+            ):
                 message = 'EOL runtime ({0}) specified. Runtime is EOL since {1} and updating will be disabled at {2}. Please consider updating to {3}'
                 matches.append(
                     RuleMatch(
@@ -30,5 +39,8 @@ class DeprecatedRuntimeEol(DeprecatedRuntime):
                             runtime_value,
                             runtime['eol'],
                             runtime['deprecated'],
-                            runtime['successor'])))
+                            runtime['successor'],
+                        ),
+                    )
+                )
         return matches
