@@ -10,18 +10,23 @@ from cfnlint.data import AdditionalSpecs
 
 class AtLeastOne(CloudFormationLintRule):
     """Check Properties Resource Configuration"""
+
     id = 'E2522'
     shortdesc = 'Check Properties that need at least one of a list of properties'
-    description = 'Making sure CloudFormation properties ' + \
-                  'that require at least one property from a list. ' + \
-                  'More than one can be included.'
+    description = (
+        'Making sure CloudFormation properties '
+        + 'that require at least one property from a list. '
+        + 'More than one can be included.'
+    )
     source_url = 'https://github.com/aws-cloudformation/cfn-python-lint'
     tags = ['resources']
 
     def __init__(self):
         """Init"""
-        super(AtLeastOne, self).__init__()
-        atleastonespec = cfnlint.helpers.load_resource(AdditionalSpecs, 'AtLeastOne.json')
+        super().__init__()
+        atleastonespec = cfnlint.helpers.load_resource(
+            AdditionalSpecs, 'AtLeastOne.json'
+        )
         self.resource_types_specs = atleastonespec['ResourceTypes']
         self.property_types_specs = atleastonespec['PropertyTypes']
         for resource_type_spec in self.resource_types_specs:
@@ -35,7 +40,9 @@ class AtLeastOne(CloudFormationLintRule):
 
         for atleastoneprop in atleastoneprops:
             for (safe_properties, safe_path) in properties.items_safe(path):
-                property_sets = cfn.get_object_without_conditions(safe_properties, atleastoneprop)
+                property_sets = cfn.get_object_without_conditions(
+                    safe_properties, atleastoneprop
+                )
                 for property_set in property_sets:
                     count = 0
                     for prop in atleastoneprop:
@@ -44,21 +51,38 @@ class AtLeastOne(CloudFormationLintRule):
 
                     if count == 0:
                         if property_set['Scenario'] is None:
-                            message = 'At least one of [{0}] should be specified for {1}'
-                            matches.append(RuleMatch(
-                                path,
-                                message.format(', '.join(map(str, atleastoneprop)),
-                                               '/'.join(map(str, safe_path)))
-                            ))
+                            message = (
+                                'At least one of [{0}] should be specified for {1}'
+                            )
+                            matches.append(
+                                RuleMatch(
+                                    path,
+                                    message.format(
+                                        ', '.join(map(str, atleastoneprop)),
+                                        '/'.join(map(str, safe_path)),
+                                    ),
+                                )
+                            )
                         else:
-                            scenario_text = ' and '.join(['when condition "%s" is %s' % (
-                                k, v) for (k, v) in property_set['Scenario'].items()])
-                            message = 'At least one of [{0}] should be specified {1} at {2}'
-                            matches.append(RuleMatch(
-                                path,
-                                message.format(', '.join(map(str, atleastoneprop)),
-                                               scenario_text, '/'.join(map(str, safe_path)))
-                            ))
+                            scenario_text = ' and '.join(
+                                [
+                                    f'when condition "{k}" is {v}'
+                                    for (k, v) in property_set['Scenario'].items()
+                                ]
+                            )
+                            message = (
+                                'At least one of [{0}] should be specified {1} at {2}'
+                            )
+                            matches.append(
+                                RuleMatch(
+                                    path,
+                                    message.format(
+                                        ', '.join(map(str, atleastoneprop)),
+                                        scenario_text,
+                                        '/'.join(map(str, safe_path)),
+                                    ),
+                                )
+                            )
 
         return matches
 
