@@ -11,13 +11,15 @@ from cfnlint.rules import RuleMatch
 
 class BasedOnValue(CloudFormationLintRule):
     """Generic rule for checking properties based on value"""
+
     spec_type = ''
     message = ''
 
     def __init__(self):
-        super(BasedOnValue, self).__init__()
+        super().__init__()
         basedonvalue = cfnlint.helpers.load_resource(
-            AdditionalSpecs, 'BasedOnValue.json')
+            AdditionalSpecs, 'BasedOnValue.json'
+        )
         self.resource_types_specs = basedonvalue['ResourceTypes']
         self.property_types_specs = basedonvalue['PropertyTypes']
         for resource_type, resource_specs in self.resource_types_specs.items():
@@ -32,7 +34,7 @@ class BasedOnValue(CloudFormationLintRule):
                         self.resource_sub_property_types.append(resource_type)
 
     def _check_value(self, value, spec, cfn):
-        """ Checks a value to see if it fits in the spec """
+        """Checks a value to see if it fits in the spec"""
         if isinstance(value, str):
             regex = spec.get('Regex')
             if regex:
@@ -45,19 +47,24 @@ class BasedOnValue(CloudFormationLintRule):
                     if ref:
                         if k == 'Ref':
                             if isinstance(v, str):
-                                return cfn.template.get('Resources').get(v, {}).get('Type') in ref
+                                return (
+                                    cfn.template.get('Resources').get(v, {}).get('Type')
+                                    in ref
+                                )
 
                     getatt = spec.get('GetAtt')
                     if getatt:
                         if k == 'Fn::GetAtt':
                             if isinstance(v, list):
-                                restype = cfn.template.get('Resources').get(v[0]).get('Type')
+                                restype = (
+                                    cfn.template.get('Resources').get(v[0]).get('Type')
+                                )
                                 if restype in getatt:
                                     return getatt.get(restype) == v[1]
 
         return False
 
-    #pylint: disable=unused-argument
+    # pylint: disable=unused-argument
     def _check_prop(self, prop, scenario):
         return False
 
@@ -69,25 +76,46 @@ class BasedOnValue(CloudFormationLintRule):
                 if spec_values:
                     property_set = [k] + spec_values
                     scenarios = cfn.get_object_without_conditions(
-                        properties, property_names=property_set)
+                        properties, property_names=property_set
+                    )
                     for scenario in scenarios:
                         if self._check_value(scenario.get('Object').get(k), s, cfn):
                             for property_name in spec_values:
                                 if self._check_prop(property_name, scenario):
                                     if scenario['Scenario'] is None:
                                         message = 'When property \'{0}\' has its current value property \'{1}\' {2} at {3}'
-                                        matches.append(RuleMatch(
-                                            path,
-                                            message.format(k, property_name,
-                                                           self.message, '/'.join(map(str, path)))
-                                        ))
+                                        matches.append(
+                                            RuleMatch(
+                                                path,
+                                                message.format(
+                                                    k,
+                                                    property_name,
+                                                    self.message,
+                                                    '/'.join(map(str, path)),
+                                                ),
+                                            )
+                                        )
                                     else:
-                                        scenario_text = ' and '.join(['when condition "%s" is %s' % (
-                                            k, v) for (k, v) in scenario['Scenario'].items()])
+                                        scenario_text = ' and '.join(
+                                            [
+                                                f'when condition "{k}" is {v}'
+                                                for (k, v) in scenario[
+                                                    'Scenario'
+                                                ].items()
+                                            ]
+                                        )
                                         message = 'When property \'{0}\' has its current value property \'{1}\' {2} when {3}'
-                                        matches.append(RuleMatch(
-                                            path,
-                                            message.format(k, property_name, self.message, scenario_text)))
+                                        matches.append(
+                                            RuleMatch(
+                                                path,
+                                                message.format(
+                                                    k,
+                                                    property_name,
+                                                    self.message,
+                                                    scenario_text,
+                                                ),
+                                            )
+                                        )
 
         return matches
 
@@ -102,9 +130,7 @@ class BasedOnValue(CloudFormationLintRule):
         # Need to get this spec
         specs = self.resource_types_specs.get(resource_type)
 
-        matches.extend(
-            self._check_obj(properties, specs, path, cfn)
-        )
+        matches.extend(self._check_obj(properties, specs, path, cfn))
 
         return matches
 
@@ -119,8 +145,6 @@ class BasedOnValue(CloudFormationLintRule):
         # Need to get this spec
         specs = self.property_types_specs.get(property_type)
 
-        matches.extend(
-            self._check_obj(properties, specs, path, cfn)
-        )
+        matches.extend(self._check_obj(properties, specs, path, cfn))
 
         return matches
